package ch.hslu.edu.enapp.webshop.boundary;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.ejb.Local;
import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.inject.Inject;

import ch.hslu.edu.enapp.webshop.boundary.webservices.msdynnav.Item;
import ch.hslu.edu.enapp.webshop.boundary.webservices.msdynnav.ItemFields;
import ch.hslu.edu.enapp.webshop.boundary.webservices.msdynnav.ItemFilter;
import ch.hslu.edu.enapp.webshop.boundary.webservices.msdynnav.ItemList;
import ch.hslu.edu.enapp.webshop.boundary.webservices.msdynnav.ItemService;
import ch.hslu.edu.enapp.webshop.common.ProductServiceLocal;
import ch.hslu.edu.enapp.webshop.common.ProductServiceRemote;
import ch.hslu.edu.enapp.webshop.common.dto.ProductDTO;
import ch.hslu.edu.enapp.webshop.control.ProductManager;

/**
 * Session Bean implementation class ProductService
 */
@Stateless
@Local(ProductServiceLocal.class)
@Remote(ProductServiceRemote.class)
public class ProductService implements ProductServiceRemote, ProductServiceLocal {

	@Inject
	ProductManager productManager;

	@Inject
	ItemService itemService;

	private List<ItemFilter> filterList;
	private ItemFilter itemFilter;

	/**
	 * Default constructor.
	 */
	public ProductService() {
		// empty
	}

	@PostConstruct
	private void init() {
		filterList = new ArrayList<ItemFilter>();
		itemFilter = new ItemFilter();

		itemFilter.setField(ItemFields.PRODUCT_GROUP_CODE);
		itemFilter.setCriteria("MP3");

		filterList.add(itemFilter);
	}

	@Override
	public List<ProductDTO> getProducts() {

		final List<ProductDTO> productList = new ArrayList<ProductDTO>();
		// Milestone 1
		// for (final Product product : productManager.getProduct()) {
		// productList.add(ProductConverter.createDTOFromEntity(product));
		// }

		// Milestone 2
		final int setSize = 10;
		int countSize = 0;
		final ItemList itemList = itemService.getItemPort().readMultiple(filterList, null, setSize);
		// productList = ProductConverter.createDTOListFromItemList(itemList);
		// setSize does not work by readMultiple() --> workaround
		for (final Item item : itemList.getItem()) {
			productList.add(ProductConverter.createDTOFromItem(item));
			countSize++;
			if (countSize >= setSize) {
				break;
			}
		}

		return productList;
	}
}
