package ch.hslu.edu.enapp.webshop.control;

import java.math.BigDecimal;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.PersistenceUnit;
import javax.persistence.Query;

import ch.hslu.edu.enapp.webshop.entity.Product;

import com.ibm.jpa.web.Action;
import com.ibm.jpa.web.JPAManager;
import com.ibm.jpa.web.NamedQueryTarget;

@SuppressWarnings("unchecked")
@JPAManager(targetEntity = ch.hslu.edu.enapp.webshop.entity.Product.class)
public class ProductManager {

	@PersistenceUnit
	private EntityManagerFactory emf;

	public ProductManager() {

	}

	private EntityManager getEntityManager() {
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public void createProduct(final Product product) throws Exception {
		final EntityManager em = getEntityManager();
		try {
			em.persist(product);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public void deleteProduct(Product product) throws Exception {
		final EntityManager em = getEntityManager();
		try {
			product = em.merge(product);
			em.remove(product);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public void updateProduct(Product product) throws Exception {
		final EntityManager em = getEntityManager();
		try {
			product = em.merge(product);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Product findProductById(final int id) {
		Product product = null;
		final EntityManager em = getEntityManager();
		try {
			product = em.find(Product.class, id);
		} finally {
			em.close();
		}
		return product;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Product getNewProduct() {

		final Product product = new Product();

		return product;
	}

	@NamedQueryTarget("getProductByUnitprice")
	public List<Product> getProductByUnitprice(final BigDecimal unitprice) {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProductByUnitprice");
			query.setParameter("unitprice", unitprice);
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getProductByName")
	public List<Product> getProductByName(final String name) {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProductByName");
			query.setParameter("name", name);
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getProductByMediapath")
	public List<Product> getProductByMediapath(final String mediapath) {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProductByMediapath");
			query.setParameter("mediapath", mediapath);
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getProductByDescription")
	public List<Product> getProductByDescription(final String description) {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProductByDescription");
			query.setParameter("description", description);
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getProductById")
	public List<Product> getProductById(final String id) {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProductById");
			query.setParameter("id", id);
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getProduct")
	public List<Product> getProduct() {
		final EntityManager em = getEntityManager();
		List<Product> results = null;
		try {
			final Query query = em.createNamedQuery("getProduct");
			results = query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

}