package ch.hslu.edu.enapp.webshop.jsf;

import java.io.Serializable;
import java.util.List;

import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;

import ch.hslu.edu.enapp.webshop.common.PurchaseServiceRemote;
import ch.hslu.edu.enapp.webshop.common.ShoppingCardServiceRemote;
import ch.hslu.edu.enapp.webshop.common.dto.ProductDTO;

@Named
@SessionScoped
public class ShoppingCart implements Serializable {

	private static final long serialVersionUID = 1L;

	@EJB
	private ShoppingCardServiceRemote shoppingCartService;

	@EJB
	private PurchaseServiceRemote purchaseService;

	public List<ProductDTO> getItems() {
		return shoppingCartService.getItems();
	}

	public void addItem(final ProductDTO product) {
		shoppingCartService.addItem(product);
	}

	public void removeItem(final ProductDTO product) {
		shoppingCartService.removeItem(product);
	}

	public int getAmountOfProduct(final ProductDTO productToRetrieve) {
		return shoppingCartService.getAmountOfProduct(productToRetrieve);
	}

	public double calculateTotal() {
		return shoppingCartService.calcTotal();
	}

	public int getCountOfItemsInBasket() {
		int total = 0;
		for (final ProductDTO product : getItems()) {
			total += getAmountOfProduct(product);
		}
		return total;
	}

	public String placeOrder() {
		final int result = purchaseService.execOrder(shoppingCartService.getShoppingCard());
		if (result > 0) {
			shoppingCartService.clear(); // remove all items from shopping cart

			// Order persist successfully
			return "/secured/orderdetail.xhtml?faces-redirect=true&id=" + result; // redirect to order view
		}

		// Order persist failed
		return "/error.xhtml?faces-redirect=true"; // redirect to error.xhtml page
	}

}
